import { Entity, Column, OneToMany, ManyToOne } from "typeorm";
import { IsInt, IsNotEmpty,} from "class-validator";
import { Participant } from "./Participant";
import { RunnerGroup } from "./RunnerGroup";
import { DistanceDonation } from "./DistanceDonation";
import { RunnerCard } from "./RunnerCard";
import { Scan } from "./Scan";

/**
 * Defines a runner.
*/
@Entity()
export class Runner extends Participant {
  /**
   * The runner's associated group.
   */
  @IsNotEmpty()
  @ManyToOne(() => RunnerGroup, group => group.runners)
  group: RunnerGroup;
  
  /**
   * Used to link runners to donations.
   */
  @OneToMany(() => DistanceDonation, distanceDonation => distanceDonation.runner)
  distanceDonations: DistanceDonation[];

  /**
   * Used to link runners to cards.
   */
  @OneToMany(() => RunnerCard, card => card.runner)
  cards: RunnerCard[];

  /**
   * Used to link runners to a scans
   */
  @OneToMany(() => Scan, scan => scan.runner)
  scans: Scan[];

  @IsInt() 
  public get distance() : number {
    return this.scans.filter(scan => scan.valid === true).reduce((sum, current) => sum + current.distance, 0);
  }
  
}
