import { PrimaryGeneratedColumn, Column, OneToMany, Entity } from "typeorm";
import {
  IsInt,
  IsNotEmpty,
  IsOptional,
  IsString,
} from "class-validator";
import { User } from "./User";

/**
 * Defines the UserGroup interface.
*/
@Entity()
export abstract class UserGroup {
  /**
   * Autogenerated unique id (primary key).
   */
  @PrimaryGeneratedColumn()
  @IsOptional()
  @IsInt()
  id: number;

  /**
   * The group's name
   */
  @Column()
  @IsNotEmpty()
  @IsString()
  name: string;

  /**
   * The group's description
   */
  @Column()
  @IsOptional()
  @IsString()
  description: string;

  /**
   * Used to link users to a user group.
   */
  //  TODO: 
  // grouppermissions: GroupPermissions[];
}